@@ -152,7 +152,7 @@ class _List(_Tag):
         value = match_obj.group(1)
         if self.name == "packages":
             if value == "-n":
-                subpackage_name = line.rsplit(" ", 1)[-1].rstrip()
+                subpackage_name = re.split(r"\s+", line)[-1].rstrip()
             else:
                 subpackage_name = f"{spec_obj.name}-{value}"
             package = Package(subpackage_name)
@@ -211,7 +211,12 @@ class _ListAndDict(_Tag):
         dictionary = getattr(spec_obj, f"{self.name}_dict")
         dictionary[source_name] = value
         target_obj = _Tag.current_target(spec_obj, context)
-        getattr(target_obj, self.name).append(value)
+        # If we are in a subpackage, add sources and patches to the subpackage dicts as well
+        if hasattr(target_obj, "is_subpackage") and target_obj.is_subpackage:
+            dictionary = getattr(target_obj, f"{self.name}_dict")
+            dictionary[source_name] = value
+            getattr(target_obj, self.name).append(value)
+        getattr(spec_obj, self.name).append(value)
         return spec_obj, context
 
 
@@ -273,10 +278,10 @@ _tags = [
     _List("conflicts", re_tag_compile(r"^Conflicts\s*:\s*(.+)")),
     _List("obsoletes", re_tag_compile(r"^Obsoletes\s*:\s*(.+)")),
     _List("provides", re_tag_compile(r"^Provides\s*:\s*(.+)")),
-    _List("packages", re.compile(r"^%package\s+(\S+)")),
-    _MacroDef("define", re.compile(r"^%define\s+(\S+)\s+(\S+)")),
-    _MacroDef("global", re.compile(r"^%global\s+(\S+)\s+(\S+)")),
-    _DummyMacroDef("dummy", re.compile(r"^%[a-z_]+\b.*$")),
+    _List("packages", re_tag_compile(r"^%package\s+(\S+)")),
+    _MacroDef("define", re_tag_compile(r"^%define\s+(\S+)\s+(\S+)")),
+    _MacroDef("global", re_tag_compile(r"^%global\s+(\S+)\s+(\S+)")),
+    _DummyMacroDef("dummy", re_tag_compile(r"^%[a-z_]+\b.*$")),
 ]
 
 _tag_names = [tag.name for tag in _tags]
@@ -408,6 +413,8 @@ class Package:
                 "conflicts",
                 "obsoletes",
                 "provides",
+                "sources",
+                "patches",
             ]:
                 setattr(self, tag.name, tag.attr_type())
             elif tag.name in [
@@ -415,6 +422,8 @@ class Package:
             ]:
                 setattr(self, tag.name, None)
 
+        self.sources_dict: Dict[str, str] = {}
+        self.patches_dict: Dict[str, str] = {}
         self.name = name
         self.is_subpackage = False
 
@@ -484,7 +493,7 @@ class Spec:
 def replace_macros(string: str, spec: Spec) -> str:
     """Replace all macros in given string with corresponding values.
 
-    For example: a string '%{name}-%{version}.tar.gz' will be transformed to 'foo-2.0.tar.gz'.
+    For example, a string '%{name}-%{version}.tar.gz' will be transformed to 'foo-2.0.tar.gz'.
 
     :param string A string containing macros that you want to be replaced.
     :param spec A Spec object. Definitions in that spec file will be used to replace macros.
@@ -494,58 +503,60 @@ def replace_macros(string: str, spec: Spec) -> str:
     """
     assert isinstance(spec, Spec)
 
-    def _first_not_none(tup: Tuple[Any, ...]) -> Any:
-        for i in tup:
-            if i is not None:
-                return i
-        raise AssertionError("All elements in tuple are None")
+    def get_first_non_none_value(values: Tuple[Any, ...]) -> Any:
+        return next((v for v in values if v is not None), None)
 
-    def _is_conditional(macro: str) -> bool:
-        return macro.startswith("?") or macro.startswith("!")
+    def is_conditional_macro(macro: str) -> bool:
+        return macro.startswith(("?", "!"))
 
-    def _test_conditional(macro: str) -> bool:
-        if macro[0] == "?":
-            return True
-        if macro[0] == "!":
-            return False
-        raise Exception("Given string is not a conditional macro")
+    def is_optional_macro(macro: str) -> bool:
+        return macro.startswith("?")
 
-    def _macro_repl(match: re.Match) -> str:
+    def is_negation_macro(macro: str) -> bool:
+        return macro.startswith("!")
+
+    def get_replacement_string(match: re.Match) -> str:
         # pylint: disable=too-many-return-statements
         groups = match.groups()
-        macro_name: str = _first_not_none(groups)
-        assert macro_name
-        if _is_conditional(macro_name) and spec:
+        macro_name: str = get_first_non_none_value(groups)
+        assert macro_name, "Expected a non None value"
+        if is_conditional_macro(macro_name) and spec:
             parts = macro_name[1:].split(sep=":", maxsplit=1)
-            assert parts
-            if _test_conditional(macro_name):
-                if hasattr(spec, parts[0]) or parts[0] in spec.macros:
+            assert parts, "Expected a ':' in macro name'"
+            macro = parts[0]
+            if is_optional_macro(macro_name):
+                if hasattr(spec, macro) or macro in spec.macros:
                     if len(parts) == 2:
                         return parts[1]
 
-                    return spec.macros.get(parts[0], getattr(spec, parts[0]))
+                    if macro in spec.macros:
+                        return spec.macros[macro]
+
+                    if hasattr(spec, macro):
+                        return getattr(spec, macro)
+
+                    assert False, "Unreachable"
 
                 return ""
 
-            if not hasattr(spec, parts[0]) and parts[0] not in spec.macros:
+            if is_negation_macro(macro_name):
                 if len(parts) == 2:
                     return parts[1]
 
-                return spec.macros.get(parts[0], getattr(spec, parts[0]))
-
-            return ""
+                return spec.macros.get(macro, getattr(spec, macro))
 
         if spec:
             value = spec.macros.get(macro_name, getattr(spec, macro_name, None))
             if value:
                 return str(value)
+
         return match.string[match.start() : match.end()]
 
     # Recursively expand macros
     # Note: If macros are not defined in the spec file, this won't try to
     # expand them.
     while True:
-        ret = re.sub(_macro_pattern, _macro_repl, string)
+        ret = re.sub(_macro_pattern, get_replacement_string, string)
         if ret != string:
             string = ret
             continue
